==> tkapi-0.2.0-py3-none-any.whl: tkapi/document.py <==
import tkapi
from tkapi.zaak import Zaak


class ParlementairDocumentFilter(tkapi.SoortFilter, tkapi.ZaakRelationFilter):

    def __init__(self):
        super().__init__()

    def filter_date_range(self, start_datetime, end_datetime):
        filter_str = "Datum ge " + tkapi.util.datetime_to_odata(start_datetime)
        self.filters.append(filter_str)
        filter_str = "Datum lt " + tkapi.util.datetime_to_odata(end_datetime)
        self.filters.append(filter_str)

    def filter_empty_agendapunt(self):
        filter_str = 'Agendapunt/any(a: true)'
        self.filters.append(filter_str)

    def filter_onderwerp(self, onderwerp):
        filter_str = 'Onderwerp eq ' + "'" + onderwerp.replace("'", "''") + "'"
        self.filters.append(filter_str)

    def filter_titel(self, titel):
        filter_str = 'Titel eq ' + "'" + titel.replace("'", "''") + "'"
        self.filters.append(filter_str)


class ParlementairDocument(tkapi.TKItem):
    url = 'ParlementairDocument'
    expand_param = 'Zaak, Activiteit, Agendapunt, Kamerstuk/Kamerstukdossier'
    orderby_param = 'Datum'

    def __init__(self, document_json):
        super().__init__(document_json)
        self.activiteiten_cache = []
        self.zaken_cache = []
        self.agendapunten_cache = []
        self.kamerstuk_cache = None
        self.dossier_cache = None

    @staticmethod
    def create_filter():
        return ParlementairDocumentFilter()

    @property
    def activiteiten(self):
        if self.activiteiten_cache:
            return self.activiteiten_cache
        from tkapi.activiteit import Activiteit
        activiteiten = []
        for activiteit_json in self.json['Activiteit']:
            activiteiten.append(tkapi.api.get_item(Activiteit, activiteit_json['Id']))
        self.activiteiten_cache = activiteiten
        return activiteiten

    @property
    def zaken(self):
        if self.zaken_cache:
            return self.zaken_cache
        zaken = []
        for zaak_json in self.json['Zaak']:
            zaken.append(tkapi.api.get_item(Zaak, zaak_json['Id']))
        self.zaken_cache = zaken
        return zaken

    @property
    def agendapunten(self):
        if self.agendapunten_cache:
            return self.agendapunten_cache
        from tkapi.agendapunt import Agendapunt
        agendapunten = []
        for agendapunt_json in self.json['Agendapunt']:
            agendapunten.append(tkapi.api.get_item(Agendapunt, agendapunt_json['Id']))
        self.agendapunten_cache = agendapunten
        return agendapunten

    @property
    def dossier(self):
        if self.dossier_cache:
            return self.dossier_cache
        from tkapi.dossier import Dossier
        dossier = tkapi.api.get_item(Dossier, self.kamerstuk['Kamerstukdossier']['Id'])
        self.dossier_cache = dossier
        return dossier

    @property
    def kamerstuk(self):
        if self.kamerstuk_cache:
            return self.kamerstuk_cache
        if self.json['Kamerstuk'] is None:
            return None
        from tkapi.kamerstuk import Kamerstuk
        kamerstuk = tkapi.api.get_item(Kamerstuk, self.json['Kamerstuk']['Id'])
        self.kamerstuk_cache = kamerstuk
        return kamerstuk

    @property
    def aanhangselnummer(self):
        return self.get_property_or_empty_string('Aanhangselnummer')

    @property
    def onderwerp(self):
        return self.get_property_or_empty_string('Onderwerp')

    @property
    def datum(self):
        return self.get_date_or_none('Datum')

    @property
    def nummer(self):
        return self.get_property_or_empty_string('Nummer')

    @property
    def soort(self):
        return self.get_property_or_empty_string('Soort')

    @property
    def titel(self):
        return self.get_property_or_empty_string('Titel')

    @property
    def vergaderjaar(self):
        return self.get_property_or_empty_string('Vergaderjaar')

    @property
    def alias(self):
        return self.get_property_or_empty_string('Alias')

    @property
    def dossier_vetnummer(self):
        if self.json['Kamerstuk'] and self.json['Kamerstuk']['Kamerstukdossier'] and self.json['Kamerstuk']['Kamerstukdossier']['Vetnummer']:
            return self.json['Kamerstuk']['Kamerstukdossier']['Vetnummer']
        return None

==> tkapi-0.5.0-py3-none-any.whl: tkapi/document.py <==
import tkapi


class ParlementairDocumentFilter(tkapi.SoortFilter, tkapi.ZaakRelationFilter):

    def filter_date_range(self, start_datetime, end_datetime):
        filter_str = "Datum ge " + tkapi.util.datetime_to_odata(start_datetime)
        self.filters.append(filter_str)
        filter_str = "Datum lt " + tkapi.util.datetime_to_odata(end_datetime)
        self.filters.append(filter_str)

    def filter_empty_agendapunt(self):
        filter_str = 'Agendapunt/any(a: true)'
        self.filters.append(filter_str)

    def filter_onderwerp(self, onderwerp):
        filter_str = 'Onderwerp eq ' + "'" + onderwerp.replace("'", "''") + "'"
        self.filters.append(filter_str)

    def filter_titel(self, titel):
        filter_str = 'Titel eq ' + "'" + titel.replace("'", "''") + "'"
        self.filters.append(filter_str)


class ParlementairDocument(tkapi.TKItemRelated, tkapi.TKItem):
    url = 'ParlementairDocument'
    # expand_param = 'Zaak'
    orderby_param = 'Datum'

    @staticmethod
    def create_filter():
        return ParlementairDocumentFilter()

    @property
    def activiteiten(self):
        from tkapi.activiteit import Activiteit
        return self.related_items(Activiteit)

    @property
    def zaken(self):
        from tkapi.zaak import Zaak
        return self.related_items(Zaak)

    @property
    def agendapunten(self):
        agendapunten = []
        for zaak in self.zaken:
            agendapunten += zaak.agendapunten
        return agendapunten

    @property
    def dossiers(self):
        if self.kamerstuk:
            return self.kamerstuk.dossiers
        return []

    @property
    def kamerstuk(self):
        from tkapi.kamerstuk import Kamerstuk
        return self.related_item(Kamerstuk)

    @property
    def aanhangselnummer(self):
        return self.get_property_or_empty_string('Aanhangselnummer')

    @property
    def onderwerp(self):
        return self.get_property_or_empty_string('Onderwerp')

    @property
    def datum(self):
        return self.get_date_from_datetime_or_none('Datum')

    @property
    def nummer(self):
        return self.get_property_or_empty_string('Nummer')

    @property
    def soort(self):
        return self.get_property_or_empty_string('Soort')

    @property
    def titel(self):
        return self.get_property_or_empty_string('Titel')

    @property
    def vergaderjaar(self):
        return self.get_property_or_empty_string('Vergaderjaar')

    @property
    def alias(self):
        return self.get_property_or_empty_string('Alias')

    @property
    def dossier_vetnummer(self):
        if self.kamerstuk and self.kamerstuk.dossier and self.kamerstuk.dossier.vetnummer:
            return self.kamerstuk.dossier.vetnummer
        return None
